==> haskell-turtle-1.5.17-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 turtle
version:              1.5.17
visibility:           public
id:                   turtle-1.5.17-2w7OVBts20tAmbOZtty0k7
key:                  turtle-1.5.17-2w7OVBts20tAmbOZtty0k7
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.

    Features include:

    * Batteries included: Command an extended suite of predefined utilities

    * Interoperability: You can still run external shell commands

    * Portability: Works on Windows, OS X, and Linux

    * Exception safety: Safely acquire and release resources

    * Streaming: Transform or fold command output in constant space

    * Patterns: Use typed regular expressions that can parse structured values

    * Formatting: Type-safe @printf@-style text formatting

    * Modern: Supports @text@ and @system-filepath@

    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide

    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.

category:             System
abi:                  6d80c715153fe369c77bb335af4f8391
exposed:              True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial

hidden-modules:       Turtle.Internal
import-dirs:          /usr/lib/ghc-8.8.3/site-local/turtle-1.5.17
library-dirs:         /usr/lib/ghc-8.8.3/site-local/turtle-1.5.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/turtle-1.5.17
hs-libraries:         HSturtle-1.5.17-2w7OVBts20tAmbOZtty0k7
depends:
    ansi-wl-pprint-0.6.9-IPiGHP9GLtPHE2cRX17Xjs
    async-2.2.2-26QXzOS0mu2H7YxyeMvEdZ base-4.13.0.0
    bytestring-0.10.10.0 clock-0.8-BDr0ZJKaVWEAskyGHHBCXi
    containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL
    foldl-1.4.6-11sOx6Hkkc2av6RgB7lcK
    hostname-1.0-AmuAwo7y3Ql7hBU6rJjFcq
    managed-1.0.7-2wFCwv0rolgGQlt0c4eY4p
    optional-args-1.0.2-7gL5IauFL6SAQfRW5EHXXe
    optparse-applicative-0.15.1.0-An71inc1YsbDQpJMiwk4K7
    process-1.6.8.0 stm-2.5.0.0
    streaming-commons-0.2.1.2-1SWSArcOZL14sNdxwxxI8J
    system-fileio-0.3.16.4-FYDpohSPVt8G4h7g2AUEt
    system-filepath-0.4.14-J2N2ocal6meL5WEn2uY5OP
    temporary-1.3-BLzMLpRlVKa3StoSFR54tr text-1.2.4.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-1FQI6nqgJsoGP4VQqT0w3a

haddock-interfaces:   /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html:         /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.5.17-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 turtle
version:              1.5.17
visibility:           public
id:                   turtle-1.5.17-32OxGhjPjRS59clkazRJoy
key:                  turtle-1.5.17-32OxGhjPjRS59clkazRJoy
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.

    Features include:

    * Batteries included: Command an extended suite of predefined utilities

    * Interoperability: You can still run external shell commands

    * Portability: Works on Windows, OS X, and Linux

    * Exception safety: Safely acquire and release resources

    * Streaming: Transform or fold command output in constant space

    * Patterns: Use typed regular expressions that can parse structured values

    * Formatting: Type-safe @printf@-style text formatting

    * Modern: Supports @text@ and @system-filepath@

    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide

    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.

category:             System
abi:                  003e1b8de954a561a1894a7237f7b929
exposed:              True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial

hidden-modules:       Turtle.Internal
import-dirs:          /usr/lib/ghc-8.8.3/site-local/turtle-1.5.17
library-dirs:         /usr/lib/ghc-8.8.3/site-local/turtle-1.5.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/turtle-1.5.17
hs-libraries:         HSturtle-1.5.17-32OxGhjPjRS59clkazRJoy
depends:
    ansi-wl-pprint-0.6.9-IPiGHP9GLtPHE2cRX17Xjs
    async-2.2.2-26QXzOS0mu2H7YxyeMvEdZ base-4.13.0.0
    bytestring-0.10.10.0 clock-0.8-BDr0ZJKaVWEAskyGHHBCXi
    containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL
    foldl-1.4.6-7f1w23NxngLq3X4Vj1mom
    hostname-1.0-AmuAwo7y3Ql7hBU6rJjFcq
    managed-1.0.7-2wFCwv0rolgGQlt0c4eY4p
    optional-args-1.0.2-7gL5IauFL6SAQfRW5EHXXe
    optparse-applicative-0.15.1.0-An71inc1YsbDQpJMiwk4K7
    process-1.6.8.0 stm-2.5.0.0
    streaming-commons-0.2.1.2-1SWSArcOZL14sNdxwxxI8J
    system-fileio-0.3.16.4-FYDpohSPVt8G4h7g2AUEt
    system-filepath-0.4.14-J2N2ocal6meL5WEn2uY5OP
    temporary-1.3-BLzMLpRlVKa3StoSFR54tr text-1.2.4.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-1FQI6nqgJsoGP4VQqT0w3a

haddock-interfaces:   /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html:         /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
